// Package yaegi provides a Go interpreter.
package yaegi

//go:generate go generate github.com/traefik/yaegi/internal/cmd/extract
//go:generate go generate github.com/traefik/yaegi/interp
//go:generate go generate github.com/traefik/yaegi/stdlib
//go:generate go generate github.com/traefik/yaegi/stdlib/syscall
//go:generate go generate github.com/traefik/yaegi/stdlib/unsafe
