// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.22
// +build go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_INET":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_UNIX":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Accept":                        reflect.ValueOf(syscall.Accept),
		"Bind":                          reflect.ValueOf(syscall.Bind),
		"BytePtrFromString":             reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":           reflect.ValueOf(syscall.ByteSliceFromString),
		"Chdir":                         reflect.ValueOf(syscall.Chdir),
		"Chmod":                         reflect.ValueOf(syscall.Chmod),
		"Chown":                         reflect.ValueOf(syscall.Chown),
		"Clearenv":                      reflect.ValueOf(syscall.Clearenv),
		"Close":                         reflect.ValueOf(syscall.Close),
		"CloseOnExec":                   reflect.ValueOf(syscall.CloseOnExec),
		"Connect":                       reflect.ValueOf(syscall.Connect),
		"Dup":                           reflect.ValueOf(syscall.Dup),
		"Dup2":                          reflect.ValueOf(syscall.Dup2),
		"E2BIG":                         reflect.ValueOf(syscall.E2BIG),
		"EACCES":                        reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                    reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                 reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EAFNOSUPPORT":                  reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                        reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                      reflect.ValueOf(syscall.EALREADY),
		"EBADF":                         reflect.ValueOf(syscall.EBADF),
		"EBADMSG":                       reflect.ValueOf(syscall.EBADMSG),
		"EBUSY":                         reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                     reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                        reflect.ValueOf(syscall.ECHILD),
		"ECONNABORTED":                  reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                  reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                    reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                       reflect.ValueOf(syscall.EDEADLK),
		"EDESTADDRREQ":                  reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                          reflect.ValueOf(syscall.EDOM),
		"EDQUOT":                        reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                        reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                        reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                         reflect.ValueOf(syscall.EFBIG),
		"EHOSTUNREACH":                  reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                         reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                        reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                   reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                         reflect.ValueOf(syscall.EINTR),
		"EINVAL":                        reflect.ValueOf(syscall.EINVAL),
		"EIO":                           reflect.ValueOf(syscall.EIO),
		"EISCONN":                       reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                        reflect.ValueOf(syscall.EISDIR),
		"ELOOP":                         reflect.ValueOf(syscall.ELOOP),
		"EMFILE":                        reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                        reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                      reflect.ValueOf(syscall.EMSGSIZE),
		"EMULTIHOP":                     reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                  reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENETDOWN":                      reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                     reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                   reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                        reflect.ValueOf(syscall.ENFILE),
		"ENOBUFS":                       reflect.ValueOf(syscall.ENOBUFS),
		"ENODEV":                        reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                        reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                       reflect.ValueOf(syscall.ENOEXEC),
		"ENOLCK":                        reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                       reflect.ValueOf(syscall.ENOLINK),
		"ENOMEM":                        reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                        reflect.ValueOf(syscall.ENOMSG),
		"ENOPROTOOPT":                   reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                        reflect.ValueOf(syscall.ENOSPC),
		"ENOSYS":                        reflect.ValueOf(syscall.ENOSYS),
		"ENOTCAPABLE":                   reflect.ValueOf(syscall.ENOTCAPABLE),
		"ENOTCONN":                      reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                       reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                     reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTRECOVERABLE":               reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTSOCK":                      reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                       reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                        reflect.ValueOf(syscall.ENOTTY),
		"ENXIO":                         reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                    reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                     reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                    reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                         reflect.ValueOf(syscall.EPERM),
		"EPIPE":                         reflect.ValueOf(syscall.EPIPE),
		"EPROTO":                        reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":               reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                    reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                        reflect.ValueOf(syscall.ERANGE),
		"EROFS":                         reflect.ValueOf(syscall.EROFS),
		"ESPIPE":                        reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                         reflect.ValueOf(syscall.ESRCH),
		"ESTALE":                        reflect.ValueOf(syscall.ESTALE),
		"ETIMEDOUT":                     reflect.ValueOf(syscall.ETIMEDOUT),
		"ETXTBSY":                       reflect.ValueOf(syscall.ETXTBSY),
		"EXDEV":                         reflect.ValueOf(syscall.EXDEV),
		"Environ":                       reflect.ValueOf(syscall.Environ),
		"FDFLAG_APPEND":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FDFLAG_DSYNC":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FDFLAG_NONBLOCK":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FDFLAG_RSYNC":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"FDFLAG_SYNC":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"FILESTAT_SET_ATIM":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILESTAT_SET_ATIM_NOW":         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILESTAT_SET_MTIM":             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILESTAT_SET_MTIM_NOW":         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"FILETYPE_BLOCK_DEVICE":         reflect.ValueOf(syscall.FILETYPE_BLOCK_DEVICE),
		"FILETYPE_CHARACTER_DEVICE":     reflect.ValueOf(syscall.FILETYPE_CHARACTER_DEVICE),
		"FILETYPE_DIRECTORY":            reflect.ValueOf(syscall.FILETYPE_DIRECTORY),
		"FILETYPE_REGULAR_FILE":         reflect.ValueOf(syscall.FILETYPE_REGULAR_FILE),
		"FILETYPE_SOCKET_DGRAM":         reflect.ValueOf(syscall.FILETYPE_SOCKET_DGRAM),
		"FILETYPE_SOCKET_STREAM":        reflect.ValueOf(syscall.FILETYPE_SOCKET_STREAM),
		"FILETYPE_SYMBOLIC_LINK":        reflect.ValueOf(syscall.FILETYPE_SYMBOLIC_LINK),
		"FILETYPE_UNKNOWN":              reflect.ValueOf(syscall.FILETYPE_UNKNOWN),
		"F_CNVT":                        reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"F_DUPFD":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLK":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_GETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_RDLCK":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_RGETLK":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_RSETLK":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_RSETLKW":                     reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"F_SETFD":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLK":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_SETLKW":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_SETOWN":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_UNLCK":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_UNLKSYS":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_WRLCK":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Fchmod":                        reflect.ValueOf(syscall.Fchmod),
		"Fchown":                        reflect.ValueOf(syscall.Fchown),
		"Fstat":                         reflect.ValueOf(syscall.Fstat),
		"Fsync":                         reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                     reflect.ValueOf(syscall.Ftruncate),
		"Getegid":                       reflect.ValueOf(syscall.Getegid),
		"Getenv":                        reflect.ValueOf(syscall.Getenv),
		"Geteuid":                       reflect.ValueOf(syscall.Geteuid),
		"Getgid":                        reflect.ValueOf(syscall.Getgid),
		"Getgroups":                     reflect.ValueOf(syscall.Getgroups),
		"Getpagesize":                   reflect.ValueOf(syscall.Getpagesize),
		"Getpid":                        reflect.ValueOf(syscall.Getpid),
		"Getppid":                       reflect.ValueOf(syscall.Getppid),
		"Getrlimit":                     reflect.ValueOf(syscall.Getrlimit),
		"GetsockoptInt":                 reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                  reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                        reflect.ValueOf(syscall.Getuid),
		"Getwd":                         reflect.ValueOf(syscall.Getwd),
		"IPPROTO_IP":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPV4":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV6":                  reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_TCP":                   reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_UDP":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_V6ONLY":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ImplementsGetwd":               reflect.ValueOf(syscall.ImplementsGetwd),
		"LOOKUP_SYMLINK_FOLLOW":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Lchown":                        reflect.ValueOf(syscall.Lchown),
		"Link":                          reflect.ValueOf(syscall.Link),
		"Listen":                        reflect.ValueOf(syscall.Listen),
		"Lstat":                         reflect.ValueOf(syscall.Lstat),
		"Mkdir":                         reflect.ValueOf(syscall.Mkdir),
		"NsecToTimespec":                reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                 reflect.ValueOf(syscall.NsecToTimeval),
		"OFLAG_CREATE":                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"OFLAG_DIRECTORY":               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"OFLAG_EXCL":                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"OFLAG_TRUNC":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"O_APPEND":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_CLOEXEC":                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_CREAT":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_CREATE":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_EXCL":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_RDONLY":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_SYNC":                        reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"O_TRUNC":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_WRONLY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                          reflect.ValueOf(syscall.Open),
		"ParseDirent":                   reflect.ValueOf(syscall.ParseDirent),
		"Pipe":                          reflect.ValueOf(syscall.Pipe),
		"Pread":                         reflect.ValueOf(syscall.Pread),
		"Pwrite":                        reflect.ValueOf(syscall.Pwrite),
		"RIGHT_FDSTAT_SET_FLAGS":        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RIGHT_FD_ADVISE":               reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RIGHT_FD_ALLOCATE":             reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RIGHT_FD_DATASYNC":             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RIGHT_FD_FILESTAT_GET":         reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RIGHT_FD_FILESTAT_SET_SIZE":    reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"RIGHT_FD_FILESTAT_SET_TIMES":   reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"RIGHT_FD_READ":                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RIGHT_FD_READDIR":              reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RIGHT_FD_SEEK":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RIGHT_FD_SYNC":                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RIGHT_FD_TELL":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RIGHT_FD_WRITE":                reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RIGHT_PATH_CREATE_DIRECTORY":   reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RIGHT_PATH_CREATE_FILE":        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RIGHT_PATH_FILESTAT_GET":       reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RIGHT_PATH_FILESTAT_SET_SIZE":  reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"RIGHT_PATH_FILESTAT_SET_TIMES": reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RIGHT_PATH_LINK_SOURCE":        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RIGHT_PATH_LINK_TARGET":        reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RIGHT_PATH_OPEN":               reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"RIGHT_PATH_READLINK":           reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RIGHT_PATH_REMOVE_DIRECTORY":   reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"RIGHT_PATH_RENAME_SOURCE":      reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RIGHT_PATH_RENAME_TARGET":      reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"RIGHT_PATH_SYMLINK":            reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"RIGHT_PATH_UNLINK_FILE":        reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"RIGHT_POLL_FD_READWRITE":       reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"RIGHT_SOCK_ACCEPT":             reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"RIGHT_SOCK_SHUTDOWN":           reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"RLIMIT_NOFILE":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RandomGet":                     reflect.ValueOf(syscall.RandomGet),
		"Read":                          reflect.ValueOf(syscall.Read),
		"ReadDir":                       reflect.ValueOf(syscall.ReadDir),
		"Readlink":                      reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                      reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                       reflect.ValueOf(syscall.Recvmsg),
		"Rename":                        reflect.ValueOf(syscall.Rename),
		"Rmdir":                         reflect.ValueOf(syscall.Rmdir),
		"SHUT_RD":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SHUT_RDWR":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SHUT_WR":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SIGABRT":                       reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                       reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                        reflect.ValueOf(syscall.SIGBUS),
		"SIGCHLD":                       reflect.ValueOf(syscall.SIGCHLD),
		"SIGCONT":                       reflect.ValueOf(syscall.SIGCONT),
		"SIGFPE":                        reflect.ValueOf(syscall.SIGFPE),
		"SIGHUP":                        reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                        reflect.ValueOf(syscall.SIGILL),
		"SIGINT":                        reflect.ValueOf(syscall.SIGINT),
		"SIGKILL":                       reflect.ValueOf(syscall.SIGKILL),
		"SIGNONE":                       reflect.ValueOf(syscall.SIGNONE),
		"SIGPIPE":                       reflect.ValueOf(syscall.SIGPIPE),
		"SIGPOLL":                       reflect.ValueOf(syscall.SIGPOLL),
		"SIGPROF":                       reflect.ValueOf(syscall.SIGPROF),
		"SIGPWR":                        reflect.ValueOf(syscall.SIGPWR),
		"SIGQUIT":                       reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                       reflect.ValueOf(syscall.SIGSEGV),
		"SIGSTOP":                       reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                        reflect.ValueOf(syscall.SIGSYS),
		"SIGTERM":                       reflect.ValueOf(syscall.SIGTERM),
		"SIGTRAP":                       reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                       reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                       reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                       reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                        reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                       reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                       reflect.ValueOf(syscall.SIGUSR2),
		"SIGVTARLM":                     reflect.ValueOf(syscall.SIGVTARLM),
		"SIGWINCH":                      reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                       reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                       reflect.ValueOf(syscall.SIGXFSZ),
		"SOCK_DGRAM":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_RAW":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_SEQPACKET":                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_STREAM":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOMAXCONN":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_ERROR":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_FCNTL":                     reflect.ValueOf(constant.MakeFromLiteral("500", token.INT, 0)),
		"S_IEXEC":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"S_IFBLK":                       reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFBOUNDSOCK":                 reflect.ValueOf(constant.MakeFromLiteral("77824", token.INT, 0)),
		"S_IFCHR":                       reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFCOND":                      reflect.ValueOf(constant.MakeFromLiteral("90112", token.INT, 0)),
		"S_IFDIR":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFDSOCK":                     reflect.ValueOf(constant.MakeFromLiteral("69632", token.INT, 0)),
		"S_IFIFO":                       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                       reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                        reflect.ValueOf(constant.MakeFromLiteral("126976", token.INT, 0)),
		"S_IFMUTEX":                     reflect.ValueOf(constant.MakeFromLiteral("86016", token.INT, 0)),
		"S_IFREG":                       reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSEMA":                      reflect.ValueOf(constant.MakeFromLiteral("94208", token.INT, 0)),
		"S_IFSHM":                       reflect.ValueOf(constant.MakeFromLiteral("81920", token.INT, 0)),
		"S_IFSHM_SYSV":                  reflect.ValueOf(constant.MakeFromLiteral("98304", token.INT, 0)),
		"S_IFSOCK":                      reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IFSOCKADDR":                  reflect.ValueOf(constant.MakeFromLiteral("73728", token.INT, 0)),
		"S_IREAD":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRGRP":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"S_IROTH":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"S_IRUSR":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                       reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_IRWXU":                       reflect.ValueOf(constant.MakeFromLiteral("448", token.INT, 0)),
		"S_ISGID":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                       reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWGRP":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"S_IWOTH":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"S_IWRITE":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IWUSR":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXGRP":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"S_IXOTH":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"S_IXUSR":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"S_UNSUP":                       reflect.ValueOf(constant.MakeFromLiteral("126976", token.INT, 0)),
		"Seek":                          reflect.ValueOf(syscall.Seek),
		"Sendfile":                      reflect.ValueOf(syscall.Sendfile),
		"SendmsgN":                      reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                        reflect.ValueOf(syscall.Sendto),
		"SetNonblock":                   reflect.ValueOf(syscall.SetNonblock),
		"SetReadDeadline":               reflect.ValueOf(syscall.SetReadDeadline),
		"SetWriteDeadline":              reflect.ValueOf(syscall.SetWriteDeadline),
		"Setenv":                        reflect.ValueOf(syscall.Setenv),
		"SetsockoptInt":                 reflect.ValueOf(syscall.SetsockoptInt),
		"Socket":                        reflect.ValueOf(syscall.Socket),
		"Stat":                          reflect.ValueOf(syscall.Stat),
		"Stderr":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Stdin":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Stdout":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"StopIO":                        reflect.ValueOf(syscall.StopIO),
		"StringBytePtr":                 reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":               reflect.ValueOf(syscall.StringByteSlice),
		"Symlink":                       reflect.ValueOf(syscall.Symlink),
		"Sysctl":                        reflect.ValueOf(syscall.Sysctl),
		"TimespecToNsec":                reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                 reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                      reflect.ValueOf(syscall.Truncate),
		"Umask":                         reflect.ValueOf(syscall.Umask),
		"Unlink":                        reflect.ValueOf(syscall.Unlink),
		"Unsetenv":                      reflect.ValueOf(syscall.Unsetenv),
		"UtimesNano":                    reflect.ValueOf(syscall.UtimesNano),
		"WHENCE_CUR":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WHENCE_END":                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"WHENCE_SET":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Wait4":                         reflect.ValueOf(syscall.Wait4),
		"Write":                         reflect.ValueOf(syscall.Write),

		// type definitions
		"Conn":          reflect.ValueOf((*syscall.Conn)(nil)),
		"Dircookie":     reflect.ValueOf((*syscall.Dircookie)(nil)),
		"Dirent":        reflect.ValueOf((*syscall.Dirent)(nil)),
		"Errno":         reflect.ValueOf((*syscall.Errno)(nil)),
		"Filetype":      reflect.ValueOf((*syscall.Filetype)(nil)),
		"ProcAttr":      reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":       reflect.ValueOf((*syscall.RawConn)(nil)),
		"Rlimit":        reflect.ValueOf((*syscall.Rlimit)(nil)),
		"Rusage":        reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":        reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":      reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrInet4": reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6": reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":  reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"Stat_t":        reflect.ValueOf((*syscall.Stat_t)(nil)),
		"SysProcAttr":   reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Timespec":      reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":       reflect.ValueOf((*syscall.Timeval)(nil)),
		"WaitStatus":    reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":     reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":  reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_Sockaddr": reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
