// Code generated by 'yaegi extract testing/slogtest'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package stdlib

import (
	"reflect"
	"testing/slogtest"
)

func init() {
	Symbols["testing/slogtest/slogtest"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"TestHandler": reflect.ValueOf(slogtest.TestHandler),
	}
}
