// Code generated by 'yaegi extract index/suffixarray'. DO NOT EDIT.

//go:build go1.22
// +build go1.22

package stdlib

import (
	"index/suffixarray"
	"reflect"
)

func init() {
	Symbols["index/suffixarray/suffixarray"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"New": reflect.ValueOf(suffixarray.New),

		// type definitions
		"Index": reflect.ValueOf((*suffixarray.Index)(nil)),
	}
}
