package main

import (
	"time"
	"time"
)

func main() {
	var t time.Time
	println(t.String())
}

// Error:
// ../_test/redeclaration-global2.go:5:2: time/redeclaration-global2.go redeclared in this block
