// Code generated by 'yaegi extract runtime/metrics'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package stdlib

import (
	"reflect"
	"runtime/metrics"
)

func init() {
	Symbols["runtime/metrics/metrics"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"All":                  reflect.ValueOf(metrics.All),
		"KindBad":              reflect.ValueOf(metrics.KindBad),
		"KindFloat64":          reflect.ValueOf(metrics.KindFloat64),
		"KindFloat64Histogram": reflect.ValueOf(metrics.KindFloat64Histogram),
		"KindUint64":           reflect.ValueOf(metrics.KindUint64),
		"Read":                 reflect.ValueOf(metrics.Read),

		// type definitions
		"Description":      reflect.ValueOf((*metrics.Description)(nil)),
		"Float64Histogram": reflect.ValueOf((*metrics.Float64Histogram)(nil)),
		"Sample":           reflect.ValueOf((*metrics.Sample)(nil)),
		"Value":            reflect.ValueOf((*metrics.Value)(nil)),
		"ValueKind":        reflect.ValueOf((*metrics.ValueKind)(nil)),
	}
}
