// Code generated by 'yaegi extract errors'. DO NOT EDIT.

//go:build go1.22
// +build go1.22

package stdlib

import (
	"errors"
	"reflect"
)

func init() {
	Symbols["errors/errors"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"As":             reflect.ValueOf(errors.As),
		"ErrUnsupported": reflect.ValueOf(&errors.ErrUnsupported).Elem(),
		"Is":             reflect.ValueOf(errors.Is),
		"Join":           reflect.ValueOf(errors.Join),
		"New":            reflect.ValueOf(errors.New),
		"Unwrap":         reflect.ValueOf(errors.Unwrap),
	}
}
