// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_INET":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                            reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_NETBIOS":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_UNIX":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"AI_CANONNAME":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AI_NUMERICHOST":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AI_PASSIVE":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"APPLICATION_ERROR":                   reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"AUTHTYPE_CLIENT":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AUTHTYPE_SERVER":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Accept":                              reflect.ValueOf(syscall.Accept),
		"AcceptEx":                            reflect.ValueOf(syscall.AcceptEx),
		"BASE_PROTOCOL":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Bind":                                reflect.ValueOf(syscall.Bind),
		"BytePtrFromString":                   reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":                 reflect.ValueOf(syscall.ByteSliceFromString),
		"CERT_CHAIN_POLICY_AUTHENTICODE":      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"CERT_CHAIN_POLICY_AUTHENTICODE_TS":   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"CERT_CHAIN_POLICY_BASE":              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"CERT_CHAIN_POLICY_BASIC_CONSTRAINTS": reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"CERT_CHAIN_POLICY_EV":                reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"CERT_CHAIN_POLICY_MICROSOFT_ROOT":    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"CERT_CHAIN_POLICY_NT_AUTH":           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"CERT_CHAIN_POLICY_SSL":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"CERT_E_CN_NO_MATCH":                  reflect.ValueOf(constant.MakeFromLiteral("2148204815", token.INT, 0)),
		"CERT_E_EXPIRED":                      reflect.ValueOf(constant.MakeFromLiteral("2148204801", token.INT, 0)),
		"CERT_E_PURPOSE":                      reflect.ValueOf(constant.MakeFromLiteral("2148204806", token.INT, 0)),
		"CERT_E_ROLE":                         reflect.ValueOf(constant.MakeFromLiteral("2148204803", token.INT, 0)),
		"CERT_E_UNTRUSTEDROOT":                reflect.ValueOf(constant.MakeFromLiteral("2148204809", token.INT, 0)),
		"CERT_STORE_ADD_ALWAYS":               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"CERT_STORE_DEFER_CLOSE_UNTIL_LAST_FREE_FLAG":  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"CERT_STORE_PROV_MEMORY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"CERT_TRUST_HAS_EXCLUDED_NAME_CONSTRAINT":      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"CERT_TRUST_HAS_NOT_DEFINED_NAME_CONSTRAINT":   reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"CERT_TRUST_HAS_NOT_PERMITTED_NAME_CONSTRAINT": reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"CERT_TRUST_HAS_NOT_SUPPORTED_CRITICAL_EXT":    reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"CERT_TRUST_HAS_NOT_SUPPORTED_NAME_CONSTRAINT": reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"CERT_TRUST_INVALID_BASIC_CONSTRAINTS":         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"CERT_TRUST_INVALID_EXTENSION":                 reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"CERT_TRUST_INVALID_NAME_CONSTRAINTS":          reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CERT_TRUST_INVALID_POLICY_CONSTRAINTS":        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"CERT_TRUST_IS_CYCLIC":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CERT_TRUST_IS_EXPLICIT_DISTRUST":              reflect.ValueOf(constant.MakeFromLiteral("67108864", token.INT, 0)),
		"CERT_TRUST_IS_NOT_SIGNATURE_VALID":            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"CERT_TRUST_IS_NOT_TIME_VALID":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"CERT_TRUST_IS_NOT_VALID_FOR_USAGE":            reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"CERT_TRUST_IS_OFFLINE_REVOCATION":             reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"CERT_TRUST_IS_REVOKED":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"CERT_TRUST_IS_UNTRUSTED_ROOT":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"CERT_TRUST_NO_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CERT_TRUST_NO_ISSUANCE_CHAIN_POLICY":          reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"CERT_TRUST_REVOCATION_STATUS_UNKNOWN":         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CREATE_ALWAYS":                                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"CREATE_NEW":                                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"CREATE_NEW_PROCESS_GROUP":                     reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"CREATE_UNICODE_ENVIRONMENT":                   reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"CRYPT_DEFAULT_CONTAINER_OPTIONAL":             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"CRYPT_DELETEKEYSET":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"CRYPT_MACHINE_KEYSET":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"CRYPT_NEWKEYSET":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"CRYPT_SILENT":                                 reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"CRYPT_VERIFYCONTEXT":                          reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"CTRL_BREAK_EVENT":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"CTRL_CLOSE_EVENT":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"CTRL_C_EVENT":                                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CTRL_LOGOFF_EVENT":                            reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"CTRL_SHUTDOWN_EVENT":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"CancelIo":                                     reflect.ValueOf(syscall.CancelIo),
		"CancelIoEx":                                   reflect.ValueOf(syscall.CancelIoEx),
		"CertAddCertificateContextToStore":             reflect.ValueOf(syscall.CertAddCertificateContextToStore),
		"CertCloseStore":                               reflect.ValueOf(syscall.CertCloseStore),
		"CertCreateCertificateContext":                 reflect.ValueOf(syscall.CertCreateCertificateContext),
		"CertEnumCertificatesInStore":                  reflect.ValueOf(syscall.CertEnumCertificatesInStore),
		"CertFreeCertificateChain":                     reflect.ValueOf(syscall.CertFreeCertificateChain),
		"CertFreeCertificateContext":                   reflect.ValueOf(syscall.CertFreeCertificateContext),
		"CertGetCertificateChain":                      reflect.ValueOf(syscall.CertGetCertificateChain),
		"CertOpenStore":                                reflect.ValueOf(syscall.CertOpenStore),
		"CertOpenSystemStore":                          reflect.ValueOf(syscall.CertOpenSystemStore),
		"CertVerifyCertificateChainPolicy":             reflect.ValueOf(syscall.CertVerifyCertificateChainPolicy),
		"Chdir":                                        reflect.ValueOf(syscall.Chdir),
		"Chmod":                                        reflect.ValueOf(syscall.Chmod),
		"Chown":                                        reflect.ValueOf(syscall.Chown),
		"Clearenv":                                     reflect.ValueOf(syscall.Clearenv),
		"Close":                                        reflect.ValueOf(syscall.Close),
		"CloseHandle":                                  reflect.ValueOf(syscall.CloseHandle),
		"CloseOnExec":                                  reflect.ValueOf(syscall.CloseOnExec),
		"Closesocket":                                  reflect.ValueOf(syscall.Closesocket),
		"CommandLineToArgv":                            reflect.ValueOf(syscall.CommandLineToArgv),
		"ComputerName":                                 reflect.ValueOf(syscall.ComputerName),
		"Connect":                                      reflect.ValueOf(syscall.Connect),
		"ConnectEx":                                    reflect.ValueOf(syscall.ConnectEx),
		"ConvertSidToStringSid":                        reflect.ValueOf(syscall.ConvertSidToStringSid),
		"ConvertStringSidToSid":                        reflect.ValueOf(syscall.ConvertStringSidToSid),
		"CopySid":                                      reflect.ValueOf(syscall.CopySid),
		"CreateDirectory":                              reflect.ValueOf(syscall.CreateDirectory),
		"CreateFile":                                   reflect.ValueOf(syscall.CreateFile),
		"CreateFileMapping":                            reflect.ValueOf(syscall.CreateFileMapping),
		"CreateHardLink":                               reflect.ValueOf(syscall.CreateHardLink),
		"CreateIoCompletionPort":                       reflect.ValueOf(syscall.CreateIoCompletionPort),
		"CreatePipe":                                   reflect.ValueOf(syscall.CreatePipe),
		"CreateProcess":                                reflect.ValueOf(syscall.CreateProcess),
		"CreateProcessAsUser":                          reflect.ValueOf(syscall.CreateProcessAsUser),
		"CreateSymbolicLink":                           reflect.ValueOf(syscall.CreateSymbolicLink),
		"CreateToolhelp32Snapshot":                     reflect.ValueOf(syscall.CreateToolhelp32Snapshot),
		"CryptAcquireContext":                          reflect.ValueOf(syscall.CryptAcquireContext),
		"CryptGenRandom":                               reflect.ValueOf(syscall.CryptGenRandom),
		"CryptReleaseContext":                          reflect.ValueOf(syscall.CryptReleaseContext),
		"DNS_INFO_NO_RECORDS":                          reflect.ValueOf(constant.MakeFromLiteral("9501", token.INT, 0)),
		"DNS_TYPE_A":                                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DNS_TYPE_A6":                                  reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"DNS_TYPE_AAAA":                                reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"DNS_TYPE_ADDRS":                               reflect.ValueOf(constant.MakeFromLiteral("248", token.INT, 0)),
		"DNS_TYPE_AFSDB":                               reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"DNS_TYPE_ALL":                                 reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"DNS_TYPE_ANY":                                 reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"DNS_TYPE_ATMA":                                reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"DNS_TYPE_AXFR":                                reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"DNS_TYPE_CERT":                                reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"DNS_TYPE_CNAME":                               reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"DNS_TYPE_DHCID":                               reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"DNS_TYPE_DNAME":                               reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"DNS_TYPE_DNSKEY":                              reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"DNS_TYPE_DS":                                  reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"DNS_TYPE_EID":                                 reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"DNS_TYPE_GID":                                 reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"DNS_TYPE_GPOS":                                reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"DNS_TYPE_HINFO":                               reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"DNS_TYPE_ISDN":                                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"DNS_TYPE_IXFR":                                reflect.ValueOf(constant.MakeFromLiteral("251", token.INT, 0)),
		"DNS_TYPE_KEY":                                 reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"DNS_TYPE_KX":                                  reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"DNS_TYPE_LOC":                                 reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"DNS_TYPE_MAILA":                               reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"DNS_TYPE_MAILB":                               reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"DNS_TYPE_MB":                                  reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"DNS_TYPE_MD":                                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"DNS_TYPE_MF":                                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DNS_TYPE_MG":                                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DNS_TYPE_MINFO":                               reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"DNS_TYPE_MR":                                  reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"DNS_TYPE_MX":                                  reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"DNS_TYPE_NAPTR":                               reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"DNS_TYPE_NBSTAT":                              reflect.ValueOf(constant.MakeFromLiteral("65281", token.INT, 0)),
		"DNS_TYPE_NIMLOC":                              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"DNS_TYPE_NS":                                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DNS_TYPE_NSAP":                                reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"DNS_TYPE_NSAPPTR":                             reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"DNS_TYPE_NSEC":                                reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"DNS_TYPE_NULL":                                reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DNS_TYPE_NXT":                                 reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"DNS_TYPE_OPT":                                 reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"DNS_TYPE_PTR":                                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DNS_TYPE_PX":                                  reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"DNS_TYPE_RP":                                  reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"DNS_TYPE_RRSIG":                               reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"DNS_TYPE_RT":                                  reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"DNS_TYPE_SIG":                                 reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"DNS_TYPE_SINK":                                reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"DNS_TYPE_SOA":                                 reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DNS_TYPE_SRV":                                 reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"DNS_TYPE_TEXT":                                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"DNS_TYPE_TKEY":                                reflect.ValueOf(constant.MakeFromLiteral("249", token.INT, 0)),
		"DNS_TYPE_TSIG":                                reflect.ValueOf(constant.MakeFromLiteral("250", token.INT, 0)),
		"DNS_TYPE_UID":                                 reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"DNS_TYPE_UINFO":                               reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"DNS_TYPE_UNSPEC":                              reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"DNS_TYPE_WINS":                                reflect.ValueOf(constant.MakeFromLiteral("65281", token.INT, 0)),
		"DNS_TYPE_WINSR":                               reflect.ValueOf(constant.MakeFromLiteral("65282", token.INT, 0)),
		"DNS_TYPE_WKS":                                 reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"DNS_TYPE_X25":                                 reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"DUPLICATE_CLOSE_SOURCE":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DUPLICATE_SAME_ACCESS":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DeleteFile":                                   reflect.ValueOf(syscall.DeleteFile),
		"DeviceIoControl":                              reflect.ValueOf(syscall.DeviceIoControl),
		"DnsNameCompare":                               reflect.ValueOf(syscall.DnsNameCompare),
		"DnsQuery":                                     reflect.ValueOf(syscall.DnsQuery),
		"DnsRecordListFree":                            reflect.ValueOf(syscall.DnsRecordListFree),
		"DnsSectionAdditional":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"DnsSectionAnswer":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DnsSectionAuthority":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DnsSectionQuestion":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DuplicateHandle":                              reflect.ValueOf(syscall.DuplicateHandle),
		"E2BIG":                                        reflect.ValueOf(syscall.E2BIG),
		"EACCES":                                       reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                                   reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                                reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EADV":                                         reflect.ValueOf(syscall.EADV),
		"EAFNOSUPPORT":                                 reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                                       reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                                     reflect.ValueOf(syscall.EALREADY),
		"EBADE":                                        reflect.ValueOf(syscall.EBADE),
		"EBADF":                                        reflect.ValueOf(syscall.EBADF),
		"EBADFD":                                       reflect.ValueOf(syscall.EBADFD),
		"EBADMSG":                                      reflect.ValueOf(syscall.EBADMSG),
		"EBADR":                                        reflect.ValueOf(syscall.EBADR),
		"EBADRQC":                                      reflect.ValueOf(syscall.EBADRQC),
		"EBADSLT":                                      reflect.ValueOf(syscall.EBADSLT),
		"EBFONT":                                       reflect.ValueOf(syscall.EBFONT),
		"EBUSY":                                        reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                                    reflect.ValueOf(syscall.ECANCELED),
		"ECHILD":                                       reflect.ValueOf(syscall.ECHILD),
		"ECHRNG":                                       reflect.ValueOf(syscall.ECHRNG),
		"ECOMM":                                        reflect.ValueOf(syscall.ECOMM),
		"ECONNABORTED":                                 reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                                 reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                                   reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                                      reflect.ValueOf(syscall.EDEADLK),
		"EDEADLOCK":                                    reflect.ValueOf(syscall.EDEADLOCK),
		"EDESTADDRREQ":                                 reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                                         reflect.ValueOf(syscall.EDOM),
		"EDOTDOT":                                      reflect.ValueOf(syscall.EDOTDOT),
		"EDQUOT":                                       reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                                       reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                                       reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                                        reflect.ValueOf(syscall.EFBIG),
		"EHOSTDOWN":                                    reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                                 reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                                        reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                                       reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                                  reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                                        reflect.ValueOf(syscall.EINTR),
		"EINVAL":                                       reflect.ValueOf(syscall.EINVAL),
		"EIO":                                          reflect.ValueOf(syscall.EIO),
		"EISCONN":                                      reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                                       reflect.ValueOf(syscall.EISDIR),
		"EISNAM":                                       reflect.ValueOf(syscall.EISNAM),
		"EKEYEXPIRED":                                  reflect.ValueOf(syscall.EKEYEXPIRED),
		"EKEYREJECTED":                                 reflect.ValueOf(syscall.EKEYREJECTED),
		"EKEYREVOKED":                                  reflect.ValueOf(syscall.EKEYREVOKED),
		"EL2HLT":                                       reflect.ValueOf(syscall.EL2HLT),
		"EL2NSYNC":                                     reflect.ValueOf(syscall.EL2NSYNC),
		"EL3HLT":                                       reflect.ValueOf(syscall.EL3HLT),
		"EL3RST":                                       reflect.ValueOf(syscall.EL3RST),
		"ELIBACC":                                      reflect.ValueOf(syscall.ELIBACC),
		"ELIBBAD":                                      reflect.ValueOf(syscall.ELIBBAD),
		"ELIBEXEC":                                     reflect.ValueOf(syscall.ELIBEXEC),
		"ELIBMAX":                                      reflect.ValueOf(syscall.ELIBMAX),
		"ELIBSCN":                                      reflect.ValueOf(syscall.ELIBSCN),
		"ELNRNG":                                       reflect.ValueOf(syscall.ELNRNG),
		"ELOOP":                                        reflect.ValueOf(syscall.ELOOP),
		"EMEDIUMTYPE":                                  reflect.ValueOf(syscall.EMEDIUMTYPE),
		"EMFILE":                                       reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                                       reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                                     reflect.ValueOf(syscall.EMSGSIZE),
		"EMULTIHOP":                                    reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                                 reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENAVAIL":                                      reflect.ValueOf(syscall.ENAVAIL),
		"ENETDOWN":                                     reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                                    reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                                  reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                                       reflect.ValueOf(syscall.ENFILE),
		"ENOANO":                                       reflect.ValueOf(syscall.ENOANO),
		"ENOBUFS":                                      reflect.ValueOf(syscall.ENOBUFS),
		"ENOCSI":                                       reflect.ValueOf(syscall.ENOCSI),
		"ENODATA":                                      reflect.ValueOf(syscall.ENODATA),
		"ENODEV":                                       reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                                       reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                                      reflect.ValueOf(syscall.ENOEXEC),
		"ENOKEY":                                       reflect.ValueOf(syscall.ENOKEY),
		"ENOLCK":                                       reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                                      reflect.ValueOf(syscall.ENOLINK),
		"ENOMEDIUM":                                    reflect.ValueOf(syscall.ENOMEDIUM),
		"ENOMEM":                                       reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                                       reflect.ValueOf(syscall.ENOMSG),
		"ENONET":                                       reflect.ValueOf(syscall.ENONET),
		"ENOPKG":                                       reflect.ValueOf(syscall.ENOPKG),
		"ENOPROTOOPT":                                  reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                                       reflect.ValueOf(syscall.ENOSPC),
		"ENOSR":                                        reflect.ValueOf(syscall.ENOSR),
		"ENOSTR":                                       reflect.ValueOf(syscall.ENOSTR),
		"ENOSYS":                                       reflect.ValueOf(syscall.ENOSYS),
		"ENOTBLK":                                      reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCONN":                                     reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                                      reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                                    reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTNAM":                                      reflect.ValueOf(syscall.ENOTNAM),
		"ENOTRECOVERABLE":                              reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTSOCK":                                     reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                                      reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                                       reflect.ValueOf(syscall.ENOTTY),
		"ENOTUNIQ":                                     reflect.ValueOf(syscall.ENOTUNIQ),
		"ENXIO":                                        reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                                   reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                                    reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                                   reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                                        reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                                 reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                                        reflect.ValueOf(syscall.EPIPE),
		"EPROTO":                                       reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":                              reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                                   reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                                       reflect.ValueOf(syscall.ERANGE),
		"EREMCHG":                                      reflect.ValueOf(syscall.EREMCHG),
		"EREMOTE":                                      reflect.ValueOf(syscall.EREMOTE),
		"EREMOTEIO":                                    reflect.ValueOf(syscall.EREMOTEIO),
		"ERESTART":                                     reflect.ValueOf(syscall.ERESTART),
		"EROFS":                                        reflect.ValueOf(syscall.EROFS),
		"ERROR_ACCESS_DENIED":                          reflect.ValueOf(syscall.ERROR_ACCESS_DENIED),
		"ERROR_ALREADY_EXISTS":                         reflect.ValueOf(syscall.ERROR_ALREADY_EXISTS),
		"ERROR_BROKEN_PIPE":                            reflect.ValueOf(syscall.ERROR_BROKEN_PIPE),
		"ERROR_BUFFER_OVERFLOW":                        reflect.ValueOf(syscall.ERROR_BUFFER_OVERFLOW),
		"ERROR_DIR_NOT_EMPTY":                          reflect.ValueOf(syscall.ERROR_DIR_NOT_EMPTY),
		"ERROR_ENVVAR_NOT_FOUND":                       reflect.ValueOf(syscall.ERROR_ENVVAR_NOT_FOUND),
		"ERROR_FILE_EXISTS":                            reflect.ValueOf(syscall.ERROR_FILE_EXISTS),
		"ERROR_FILE_NOT_FOUND":                         reflect.ValueOf(syscall.ERROR_FILE_NOT_FOUND),
		"ERROR_HANDLE_EOF":                             reflect.ValueOf(syscall.ERROR_HANDLE_EOF),
		"ERROR_INSUFFICIENT_BUFFER":                    reflect.ValueOf(syscall.ERROR_INSUFFICIENT_BUFFER),
		"ERROR_IO_PENDING":                             reflect.ValueOf(syscall.ERROR_IO_PENDING),
		"ERROR_MOD_NOT_FOUND":                          reflect.ValueOf(syscall.ERROR_MOD_NOT_FOUND),
		"ERROR_MORE_DATA":                              reflect.ValueOf(syscall.ERROR_MORE_DATA),
		"ERROR_NETNAME_DELETED":                        reflect.ValueOf(syscall.ERROR_NETNAME_DELETED),
		"ERROR_NOT_FOUND":                              reflect.ValueOf(syscall.ERROR_NOT_FOUND),
		"ERROR_NO_MORE_FILES":                          reflect.ValueOf(syscall.ERROR_NO_MORE_FILES),
		"ERROR_OPERATION_ABORTED":                      reflect.ValueOf(syscall.ERROR_OPERATION_ABORTED),
		"ERROR_PATH_NOT_FOUND":                         reflect.ValueOf(syscall.ERROR_PATH_NOT_FOUND),
		"ERROR_PRIVILEGE_NOT_HELD":                     reflect.ValueOf(syscall.ERROR_PRIVILEGE_NOT_HELD),
		"ERROR_PROC_NOT_FOUND":                         reflect.ValueOf(syscall.ERROR_PROC_NOT_FOUND),
		"ESHUTDOWN":                                    reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":                              reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESPIPE":                                       reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                                        reflect.ValueOf(syscall.ESRCH),
		"ESRMNT":                                       reflect.ValueOf(syscall.ESRMNT),
		"ESTALE":                                       reflect.ValueOf(syscall.ESTALE),
		"ESTRPIPE":                                     reflect.ValueOf(syscall.ESTRPIPE),
		"ETIME":                                        reflect.ValueOf(syscall.ETIME),
		"ETIMEDOUT":                                    reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                                 reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                                      reflect.ValueOf(syscall.ETXTBSY),
		"EUCLEAN":                                      reflect.ValueOf(syscall.EUCLEAN),
		"EUNATCH":                                      reflect.ValueOf(syscall.EUNATCH),
		"EUSERS":                                       reflect.ValueOf(syscall.EUSERS),
		"EWINDOWS":                                     reflect.ValueOf(syscall.EWINDOWS),
		"EWOULDBLOCK":                                  reflect.ValueOf(syscall.EWOULDBLOCK),
		"EXDEV":                                        reflect.ValueOf(syscall.EXDEV),
		"EXFULL":                                       reflect.ValueOf(syscall.EXFULL),
		"Environ":                                      reflect.ValueOf(syscall.Environ),
		"EscapeArg":                                    reflect.ValueOf(syscall.EscapeArg),
		"FILE_ACTION_ADDED":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_ACTION_MODIFIED":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"FILE_ACTION_REMOVED":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_ACTION_RENAMED_NEW_NAME":                 reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"FILE_ACTION_RENAMED_OLD_NAME":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_APPEND_DATA":                             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_ATTRIBUTE_ARCHIVE":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"FILE_ATTRIBUTE_DIRECTORY":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"FILE_ATTRIBUTE_HIDDEN":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_ATTRIBUTE_NORMAL":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"FILE_ATTRIBUTE_READONLY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_ATTRIBUTE_REPARSE_POINT":                 reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"FILE_ATTRIBUTE_SYSTEM":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_BEGIN":                                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"FILE_CURRENT":                                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_END":                                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_FLAG_BACKUP_SEMANTICS":                   reflect.ValueOf(constant.MakeFromLiteral("33554432", token.INT, 0)),
		"FILE_FLAG_OPEN_REPARSE_POINT":                 reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"FILE_FLAG_OVERLAPPED":                         reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"FILE_LIST_DIRECTORY":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_MAP_COPY":                                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_MAP_EXECUTE":                             reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"FILE_MAP_READ":                                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_MAP_WRITE":                               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_ATTRIBUTES":                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_CREATION":                  reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_DIR_NAME":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_FILE_NAME":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_LAST_ACCESS":               reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_LAST_WRITE":                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"FILE_NOTIFY_CHANGE_SIZE":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"FILE_SHARE_DELETE":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"FILE_SHARE_READ":                              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_SHARE_WRITE":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_SKIP_COMPLETION_PORT_ON_SUCCESS":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_SKIP_SET_EVENT_ON_HANDLE":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_TYPE_CHAR":                               reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"FILE_TYPE_DISK":                               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FILE_TYPE_PIPE":                               reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"FILE_TYPE_REMOTE":                             reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"FILE_TYPE_UNKNOWN":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"FILE_WRITE_ATTRIBUTES":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"FORMAT_MESSAGE_ALLOCATE_BUFFER":               reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"FORMAT_MESSAGE_ARGUMENT_ARRAY":                reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"FORMAT_MESSAGE_FROM_HMODULE":                  reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"FORMAT_MESSAGE_FROM_STRING":                   reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"FORMAT_MESSAGE_FROM_SYSTEM":                   reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"FORMAT_MESSAGE_IGNORE_INSERTS":                reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"FORMAT_MESSAGE_MAX_WIDTH_MASK":                reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"FSCTL_GET_REPARSE_POINT":                      reflect.ValueOf(constant.MakeFromLiteral("589992", token.INT, 0)),
		"Fchdir":                                       reflect.ValueOf(syscall.Fchdir),
		"Fchmod":                                       reflect.ValueOf(syscall.Fchmod),
		"Fchown":                                       reflect.ValueOf(syscall.Fchown),
		"FindClose":                                    reflect.ValueOf(syscall.FindClose),
		"FindFirstFile":                                reflect.ValueOf(syscall.FindFirstFile),
		"FindNextFile":                                 reflect.ValueOf(syscall.FindNextFile),
		"FlushFileBuffers":                             reflect.ValueOf(syscall.FlushFileBuffers),
		"FlushViewOfFile":                              reflect.ValueOf(syscall.FlushViewOfFile),
		"ForkLock":                                     reflect.ValueOf(&syscall.ForkLock).Elem(),
		"FormatMessage":                                reflect.ValueOf(syscall.FormatMessage),
		"FreeAddrInfoW":                                reflect.ValueOf(syscall.FreeAddrInfoW),
		"FreeEnvironmentStrings":                       reflect.ValueOf(syscall.FreeEnvironmentStrings),
		"FreeLibrary":                                  reflect.ValueOf(syscall.FreeLibrary),
		"Fsync":                                        reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                                    reflect.ValueOf(syscall.Ftruncate),
		"FullPath":                                     reflect.ValueOf(syscall.FullPath),
		"GENERIC_ALL":                                  reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"GENERIC_EXECUTE":                              reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"GENERIC_READ":                                 reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"GENERIC_WRITE":                                reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"GetAcceptExSockaddrs":                         reflect.ValueOf(syscall.GetAcceptExSockaddrs),
		"GetAdaptersInfo":                              reflect.ValueOf(syscall.GetAdaptersInfo),
		"GetAddrInfoW":                                 reflect.ValueOf(syscall.GetAddrInfoW),
		"GetCommandLine":                               reflect.ValueOf(syscall.GetCommandLine),
		"GetComputerName":                              reflect.ValueOf(syscall.GetComputerName),
		"GetConsoleMode":                               reflect.ValueOf(syscall.GetConsoleMode),
		"GetCurrentDirectory":                          reflect.ValueOf(syscall.GetCurrentDirectory),
		"GetCurrentProcess":                            reflect.ValueOf(syscall.GetCurrentProcess),
		"GetEnvironmentStrings":                        reflect.ValueOf(syscall.GetEnvironmentStrings),
		"GetEnvironmentVariable":                       reflect.ValueOf(syscall.GetEnvironmentVariable),
		"GetFileAttributes":                            reflect.ValueOf(syscall.GetFileAttributes),
		"GetFileAttributesEx":                          reflect.ValueOf(syscall.GetFileAttributesEx),
		"GetFileExInfoStandard":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"GetFileExMaxInfoLevel":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"GetFileInformationByHandle":                   reflect.ValueOf(syscall.GetFileInformationByHandle),
		"GetFileType":                                  reflect.ValueOf(syscall.GetFileType),
		"GetFullPathName":                              reflect.ValueOf(syscall.GetFullPathName),
		"GetHostByName":                                reflect.ValueOf(syscall.GetHostByName),
		"GetIfEntry":                                   reflect.ValueOf(syscall.GetIfEntry),
		"GetLastError":                                 reflect.ValueOf(syscall.GetLastError),
		"GetLengthSid":                                 reflect.ValueOf(syscall.GetLengthSid),
		"GetLongPathName":                              reflect.ValueOf(syscall.GetLongPathName),
		"GetProcAddress":                               reflect.ValueOf(syscall.GetProcAddress),
		"GetProcessTimes":                              reflect.ValueOf(syscall.GetProcessTimes),
		"GetProtoByName":                               reflect.ValueOf(syscall.GetProtoByName),
		"GetQueuedCompletionStatus":                    reflect.ValueOf(syscall.GetQueuedCompletionStatus),
		"GetServByName":                                reflect.ValueOf(syscall.GetServByName),
		"GetShortPathName":                             reflect.ValueOf(syscall.GetShortPathName),
		"GetStartupInfo":                               reflect.ValueOf(syscall.GetStartupInfo),
		"GetStdHandle":                                 reflect.ValueOf(syscall.GetStdHandle),
		"GetSystemTimeAsFileTime":                      reflect.ValueOf(syscall.GetSystemTimeAsFileTime),
		"GetTempPath":                                  reflect.ValueOf(syscall.GetTempPath),
		"GetTimeZoneInformation":                       reflect.ValueOf(syscall.GetTimeZoneInformation),
		"GetTokenInformation":                          reflect.ValueOf(syscall.GetTokenInformation),
		"GetUserNameEx":                                reflect.ValueOf(syscall.GetUserNameEx),
		"GetUserProfileDirectory":                      reflect.ValueOf(syscall.GetUserProfileDirectory),
		"GetVersion":                                   reflect.ValueOf(syscall.GetVersion),
		"Getegid":                                      reflect.ValueOf(syscall.Getegid),
		"Getenv":                                       reflect.ValueOf(syscall.Getenv),
		"Geteuid":                                      reflect.ValueOf(syscall.Geteuid),
		"Getgid":                                       reflect.ValueOf(syscall.Getgid),
		"Getgroups":                                    reflect.ValueOf(syscall.Getgroups),
		"Getpagesize":                                  reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                                  reflect.ValueOf(syscall.Getpeername),
		"Getpid":                                       reflect.ValueOf(syscall.Getpid),
		"Getppid":                                      reflect.ValueOf(syscall.Getppid),
		"Getsockname":                                  reflect.ValueOf(syscall.Getsockname),
		"Getsockopt":                                   reflect.ValueOf(syscall.Getsockopt),
		"GetsockoptInt":                                reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                                 reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                                       reflect.ValueOf(syscall.Getuid),
		"Getwd":                                        reflect.ValueOf(syscall.Getwd),
		"HANDLE_FLAG_INHERIT":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"HKEY_CLASSES_ROOT":                            reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"HKEY_CURRENT_CONFIG":                          reflect.ValueOf(constant.MakeFromLiteral("2147483653", token.INT, 0)),
		"HKEY_CURRENT_USER":                            reflect.ValueOf(constant.MakeFromLiteral("2147483649", token.INT, 0)),
		"HKEY_DYN_DATA":                                reflect.ValueOf(constant.MakeFromLiteral("2147483654", token.INT, 0)),
		"HKEY_LOCAL_MACHINE":                           reflect.ValueOf(constant.MakeFromLiteral("2147483650", token.INT, 0)),
		"HKEY_PERFORMANCE_DATA":                        reflect.ValueOf(constant.MakeFromLiteral("2147483652", token.INT, 0)),
		"HKEY_USERS":                                   reflect.ValueOf(constant.MakeFromLiteral("2147483651", token.INT, 0)),
		"IFF_BROADCAST":                                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_LOOPBACK":                                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_MULTICAST":                                reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_POINTTOPOINT":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_UP":                                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNORE":                                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"INFINITE":                                     reflect.ValueOf(constant.MakeFromLiteral("4294967295", token.INT, 0)),
		"INVALID_FILE_ATTRIBUTES":                      reflect.ValueOf(constant.MakeFromLiteral("4294967295", token.INT, 0)),
		"IOC_IN":                                       reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"IOC_INOUT":                                    reflect.ValueOf(constant.MakeFromLiteral("3221225472", token.INT, 0)),
		"IOC_OUT":                                      reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"IOC_VENDOR":                                   reflect.ValueOf(constant.MakeFromLiteral("402653184", token.INT, 0)),
		"IOC_WS2":                                      reflect.ValueOf(constant.MakeFromLiteral("134217728", token.INT, 0)),
		"IO_REPARSE_TAG_SYMLINK":                       reflect.ValueOf(constant.MakeFromLiteral("2684354572", token.INT, 0)),
		"IPPROTO_IP":                                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPV6":                                 reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_TCP":                                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_UDP":                                  reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPV6_JOIN_GROUP":                              reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_LEAVE_GROUP":                             reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_MULTICAST_IF":                            reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPV6_UNICAST_HOPS":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_V6ONLY":                                  reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":                            reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":                           reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IP_MULTICAST_IF":                              reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_MULTICAST_LOOP":                            reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_MULTICAST_TTL":                             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_TOS":                                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_TTL":                                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ImplementsGetwd":                              reflect.ValueOf(syscall.ImplementsGetwd),
		"InvalidHandle":                                reflect.ValueOf(syscall.InvalidHandle),
		"KEY_ALL_ACCESS":                               reflect.ValueOf(constant.MakeFromLiteral("983103", token.INT, 0)),
		"KEY_CREATE_LINK":                              reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"KEY_CREATE_SUB_KEY":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"KEY_ENUMERATE_SUB_KEYS":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"KEY_EXECUTE":                                  reflect.ValueOf(constant.MakeFromLiteral("131097", token.INT, 0)),
		"KEY_NOTIFY":                                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"KEY_QUERY_VALUE":                              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"KEY_READ":                                     reflect.ValueOf(constant.MakeFromLiteral("131097", token.INT, 0)),
		"KEY_SET_VALUE":                                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"KEY_WOW64_32KEY":                              reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"KEY_WOW64_64KEY":                              reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"KEY_WRITE":                                    reflect.ValueOf(constant.MakeFromLiteral("131078", token.INT, 0)),
		"LANG_ENGLISH":                                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"LAYERED_PROTOCOL":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Lchown":                                       reflect.ValueOf(syscall.Lchown),
		"Link":                                         reflect.ValueOf(syscall.Link),
		"Listen":                                       reflect.ValueOf(syscall.Listen),
		"LoadCancelIoEx":                               reflect.ValueOf(syscall.LoadCancelIoEx),
		"LoadConnectEx":                                reflect.ValueOf(syscall.LoadConnectEx),
		"LoadCreateSymbolicLink":                       reflect.ValueOf(syscall.LoadCreateSymbolicLink),
		"LoadDLL":                                      reflect.ValueOf(syscall.LoadDLL),
		"LoadGetAddrInfo":                              reflect.ValueOf(syscall.LoadGetAddrInfo),
		"LoadLibrary":                                  reflect.ValueOf(syscall.LoadLibrary),
		"LoadSetFileCompletionNotificationModes":       reflect.ValueOf(syscall.LoadSetFileCompletionNotificationModes),
		"LocalFree":                                    reflect.ValueOf(syscall.LocalFree),
		"LookupAccountName":                            reflect.ValueOf(syscall.LookupAccountName),
		"LookupAccountSid":                             reflect.ValueOf(syscall.LookupAccountSid),
		"LookupSID":                                    reflect.ValueOf(syscall.LookupSID),
		"MAXIMUM_REPARSE_DATA_BUFFER_SIZE":             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MAXLEN_IFDESCR":                               reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAXLEN_PHYSADDR":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MAX_ADAPTER_ADDRESS_LENGTH":                   reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MAX_ADAPTER_DESCRIPTION_LENGTH":               reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MAX_ADAPTER_NAME_LENGTH":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAX_COMPUTERNAME_LENGTH":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"MAX_INTERFACE_NAME_LEN":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAX_LONG_PATH":                                reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MAX_PATH":                                     reflect.ValueOf(constant.MakeFromLiteral("260", token.INT, 0)),
		"MAX_PROTOCOL_CHAIN":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"MapViewOfFile":                                reflect.ValueOf(syscall.MapViewOfFile),
		"MaxTokenInfoClass":                            reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"Mkdir":                                        reflect.ValueOf(syscall.Mkdir),
		"MoveFile":                                     reflect.ValueOf(syscall.MoveFile),
		"MustLoadDLL":                                  reflect.ValueOf(syscall.MustLoadDLL),
		"NameCanonical":                                reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"NameCanonicalEx":                              reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"NameDisplay":                                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NameDnsDomain":                                reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"NameFullyQualifiedDN":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NameSamCompatible":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NameServicePrincipal":                         reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"NameUniqueId":                                 reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"NameUnknown":                                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"NameUserPrincipal":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NetApiBufferFree":                             reflect.ValueOf(syscall.NetApiBufferFree),
		"NetGetJoinInformation":                        reflect.ValueOf(syscall.NetGetJoinInformation),
		"NetSetupDomainName":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NetSetupUnjoined":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NetSetupUnknownStatus":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"NetSetupWorkgroupName":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NetUserGetInfo":                               reflect.ValueOf(syscall.NetUserGetInfo),
		"NewCallback":                                  reflect.ValueOf(syscall.NewCallback),
		"NewCallbackCDecl":                             reflect.ValueOf(syscall.NewCallbackCDecl),
		"NewLazyDLL":                                   reflect.ValueOf(syscall.NewLazyDLL),
		"NsecToFiletime":                               reflect.ValueOf(syscall.NsecToFiletime),
		"NsecToTimespec":                               reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                                reflect.ValueOf(syscall.NsecToTimeval),
		"Ntohs":                                        reflect.ValueOf(syscall.Ntohs),
		"OID_PKIX_KP_SERVER_AUTH":                      reflect.ValueOf(&syscall.OID_PKIX_KP_SERVER_AUTH).Elem(),
		"OID_SERVER_GATED_CRYPTO":                      reflect.ValueOf(&syscall.OID_SERVER_GATED_CRYPTO).Elem(),
		"OID_SGC_NETSCAPE":                             reflect.ValueOf(&syscall.OID_SGC_NETSCAPE).Elem(),
		"OPEN_ALWAYS":                                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"OPEN_EXISTING":                                reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"O_APPEND":                                     reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_ASYNC":                                      reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"O_CLOEXEC":                                    reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"O_CREAT":                                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_EXCL":                                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_NOCTTY":                                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_NONBLOCK":                                   reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_RDONLY":                                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_SYNC":                                       reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"O_TRUNC":                                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_WRONLY":                                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                                         reflect.ValueOf(syscall.Open),
		"OpenCurrentProcessToken":                      reflect.ValueOf(syscall.OpenCurrentProcessToken),
		"OpenProcess":                                  reflect.ValueOf(syscall.OpenProcess),
		"OpenProcessToken":                             reflect.ValueOf(syscall.OpenProcessToken),
		"PAGE_EXECUTE_READ":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"PAGE_EXECUTE_READWRITE":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"PAGE_EXECUTE_WRITECOPY":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"PAGE_READONLY":                                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PAGE_READWRITE":                               reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PAGE_WRITECOPY":                               reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PFL_HIDDEN":                                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PFL_MATCHES_PROTOCOL_ZERO":                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PFL_MULTIPLE_PROTO_ENTRIES":                   reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PFL_NETWORKDIRECT_PROVIDER":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PFL_RECOMMENDED_PROTO_ENTRY":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PKCS_7_ASN_ENCODING":                          reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"PROCESS_QUERY_INFORMATION":                    reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"PROCESS_TERMINATE":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROV_DH_SCHANNEL":                             reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"PROV_DSS":                                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"PROV_DSS_DH":                                  reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"PROV_EC_ECDSA_FULL":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"PROV_EC_ECDSA_SIG":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"PROV_EC_ECNRA_FULL":                           reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"PROV_EC_ECNRA_SIG":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"PROV_FORTEZZA":                                reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROV_INTEL_SEC":                               reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"PROV_MS_EXCHANGE":                             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"PROV_REPLACE_OWF":                             reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"PROV_RNG":                                     reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"PROV_RSA_AES":                                 reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"PROV_RSA_FULL":                                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROV_RSA_SCHANNEL":                            reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"PROV_RSA_SIG":                                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROV_SPYRUS_LYNKS":                            reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"PROV_SSL":                                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"Pipe":                                         reflect.ValueOf(syscall.Pipe),
		"PostQueuedCompletionStatus":                   reflect.ValueOf(syscall.PostQueuedCompletionStatus),
		"Process32First":                               reflect.ValueOf(syscall.Process32First),
		"Process32Next":                                reflect.ValueOf(syscall.Process32Next),
		"REG_BINARY":                                   reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"REG_DWORD":                                    reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"REG_DWORD_BIG_ENDIAN":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"REG_DWORD_LITTLE_ENDIAN":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"REG_EXPAND_SZ":                                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"REG_FULL_RESOURCE_DESCRIPTOR":                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"REG_LINK":                                     reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"REG_MULTI_SZ":                                 reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"REG_NONE":                                     reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"REG_QWORD":                                    reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"REG_QWORD_LITTLE_ENDIAN":                      reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"REG_RESOURCE_LIST":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"REG_RESOURCE_REQUIREMENTS_LIST":               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"REG_SZ":                                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Read":                                         reflect.ValueOf(syscall.Read),
		"ReadConsole":                                  reflect.ValueOf(syscall.ReadConsole),
		"ReadDirectoryChanges":                         reflect.ValueOf(syscall.ReadDirectoryChanges),
		"ReadFile":                                     reflect.ValueOf(syscall.ReadFile),
		"Readlink":                                     reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                                     reflect.ValueOf(syscall.Recvfrom),
		"RegCloseKey":                                  reflect.ValueOf(syscall.RegCloseKey),
		"RegEnumKeyEx":                                 reflect.ValueOf(syscall.RegEnumKeyEx),
		"RegOpenKeyEx":                                 reflect.ValueOf(syscall.RegOpenKeyEx),
		"RegQueryInfoKey":                              reflect.ValueOf(syscall.RegQueryInfoKey),
		"RegQueryValueEx":                              reflect.ValueOf(syscall.RegQueryValueEx),
		"RemoveDirectory":                              reflect.ValueOf(syscall.RemoveDirectory),
		"Rename":                                       reflect.ValueOf(syscall.Rename),
		"Rmdir":                                        reflect.ValueOf(syscall.Rmdir),
		"SHUT_RD":                                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                                    reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIGABRT":                                      reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                                      reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                                       reflect.ValueOf(syscall.SIGBUS),
		"SIGFPE":                                       reflect.ValueOf(syscall.SIGFPE),
		"SIGHUP":                                       reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                                       reflect.ValueOf(syscall.SIGILL),
		"SIGINT":                                       reflect.ValueOf(syscall.SIGINT),
		"SIGKILL":                                      reflect.ValueOf(syscall.SIGKILL),
		"SIGPIPE":                                      reflect.ValueOf(syscall.SIGPIPE),
		"SIGQUIT":                                      reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                                      reflect.ValueOf(syscall.SIGSEGV),
		"SIGTERM":                                      reflect.ValueOf(syscall.SIGTERM),
		"SIGTRAP":                                      reflect.ValueOf(syscall.SIGTRAP),
		"SIO_GET_EXTENSION_FUNCTION_POINTER":           reflect.ValueOf(constant.MakeFromLiteral("3355443206", token.INT, 0)),
		"SIO_GET_INTERFACE_LIST":                       reflect.ValueOf(constant.MakeFromLiteral("1074033791", token.INT, 0)),
		"SIO_KEEPALIVE_VALS":                           reflect.ValueOf(constant.MakeFromLiteral("2550136836", token.INT, 0)),
		"SIO_UDP_CONNRESET":                            reflect.ValueOf(constant.MakeFromLiteral("2550136844", token.INT, 0)),
		"SOCK_DGRAM":                                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_RAW":                                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_SEQPACKET":                               reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_STREAM":                                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_SOCKET":                                   reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOMAXCONN":                                    reflect.ValueOf(constant.MakeFromLiteral("2147483647", token.INT, 0)),
		"SO_BROADCAST":                                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_DONTROUTE":                                 reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_KEEPALIVE":                                 reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_LINGER":                                    reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_RCVBUF":                                    reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"SO_REUSEADDR":                                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_SNDBUF":                                    reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"SO_UPDATE_ACCEPT_CONTEXT":                     reflect.ValueOf(constant.MakeFromLiteral("28683", token.INT, 0)),
		"SO_UPDATE_CONNECT_CONTEXT":                    reflect.ValueOf(constant.MakeFromLiteral("28688", token.INT, 0)),
		"STANDARD_RIGHTS_ALL":                          reflect.ValueOf(constant.MakeFromLiteral("2031616", token.INT, 0)),
		"STANDARD_RIGHTS_EXECUTE":                      reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"STANDARD_RIGHTS_READ":                         reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"STANDARD_RIGHTS_REQUIRED":                     reflect.ValueOf(constant.MakeFromLiteral("983040", token.INT, 0)),
		"STANDARD_RIGHTS_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"STARTF_USESHOWWINDOW":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"STARTF_USESTDHANDLES":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"STD_ERROR_HANDLE":                             reflect.ValueOf(constant.MakeFromLiteral("-12", token.INT, 0)),
		"STD_INPUT_HANDLE":                             reflect.ValueOf(constant.MakeFromLiteral("-10", token.INT, 0)),
		"STD_OUTPUT_HANDLE":                            reflect.ValueOf(constant.MakeFromLiteral("-11", token.INT, 0)),
		"SUBLANG_ENGLISH_US":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SW_FORCEMINIMIZE":                             reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"SW_HIDE":                                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SW_MAXIMIZE":                                  reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SW_MINIMIZE":                                  reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SW_NORMAL":                                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SW_RESTORE":                                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SW_SHOW":                                      reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SW_SHOWDEFAULT":                               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SW_SHOWMAXIMIZED":                             reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SW_SHOWMINIMIZED":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SW_SHOWMINNOACTIVE":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SW_SHOWNA":                                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SW_SHOWNOACTIVATE":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SW_SHOWNORMAL":                                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SYMBOLIC_LINK_FLAG_DIRECTORY":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SYNCHRONIZE":                                  reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"S_IFBLK":                                      reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                                      reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                                      reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                                      reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                                      reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                                       reflect.ValueOf(constant.MakeFromLiteral("126976", token.INT, 0)),
		"S_IFREG":                                      reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                                     reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IRUSR":                                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_ISGID":                                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWRITE":                                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IWUSR":                                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXUSR":                                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                                         reflect.ValueOf(syscall.Seek),
		"Sendto":                                       reflect.ValueOf(syscall.Sendto),
		"SetCurrentDirectory":                          reflect.ValueOf(syscall.SetCurrentDirectory),
		"SetEndOfFile":                                 reflect.ValueOf(syscall.SetEndOfFile),
		"SetEnvironmentVariable":                       reflect.ValueOf(syscall.SetEnvironmentVariable),
		"SetFileAttributes":                            reflect.ValueOf(syscall.SetFileAttributes),
		"SetFileCompletionNotificationModes":           reflect.ValueOf(syscall.SetFileCompletionNotificationModes),
		"SetFilePointer":                               reflect.ValueOf(syscall.SetFilePointer),
		"SetFileTime":                                  reflect.ValueOf(syscall.SetFileTime),
		"SetHandleInformation":                         reflect.ValueOf(syscall.SetHandleInformation),
		"SetNonblock":                                  reflect.ValueOf(syscall.SetNonblock),
		"Setenv":                                       reflect.ValueOf(syscall.Setenv),
		"Setsockopt":                                   reflect.ValueOf(syscall.Setsockopt),
		"SetsockoptIPMreq":                             reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPv6Mreq":                           reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":                          reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                                reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":                             reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptTimeval":                            reflect.ValueOf(syscall.SetsockoptTimeval),
		"SidTypeAlias":                                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SidTypeComputer":                              reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SidTypeDeletedAccount":                        reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SidTypeDomain":                                reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SidTypeGroup":                                 reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SidTypeInvalid":                               reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SidTypeLabel":                                 reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SidTypeUnknown":                               reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SidTypeUser":                                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SidTypeWellKnownGroup":                        reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"Socket":                                       reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":                            reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Stderr":                                       reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                                        reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                                       reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                                reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":                              reflect.ValueOf(syscall.StringByteSlice),
		"StringToSid":                                  reflect.ValueOf(syscall.StringToSid),
		"StringToUTF16":                                reflect.ValueOf(syscall.StringToUTF16),
		"StringToUTF16Ptr":                             reflect.ValueOf(syscall.StringToUTF16Ptr),
		"Symlink":                                      reflect.ValueOf(syscall.Symlink),
		"TCP_NODELAY":                                  reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TF_DISCONNECT":                                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TF_REUSE_SOCKET":                              reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TF_USE_DEFAULT_WORKER":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TF_USE_KERNEL_APC":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TF_USE_SYSTEM_THREAD":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TF_WRITE_BEHIND":                              reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TH32CS_INHERIT":                               reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"TH32CS_SNAPALL":                               reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"TH32CS_SNAPHEAPLIST":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TH32CS_SNAPMODULE":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TH32CS_SNAPMODULE32":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TH32CS_SNAPPROCESS":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TH32CS_SNAPTHREAD":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIME_ZONE_ID_DAYLIGHT":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIME_ZONE_ID_STANDARD":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIME_ZONE_ID_UNKNOWN":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TOKEN_ADJUST_DEFAULT":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TOKEN_ADJUST_GROUPS":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TOKEN_ADJUST_PRIVILEGES":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TOKEN_ADJUST_SESSIONID":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TOKEN_ALL_ACCESS":                             reflect.ValueOf(constant.MakeFromLiteral("983551", token.INT, 0)),
		"TOKEN_ASSIGN_PRIMARY":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TOKEN_DUPLICATE":                              reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TOKEN_EXECUTE":                                reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"TOKEN_IMPERSONATE":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TOKEN_QUERY":                                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TOKEN_QUERY_SOURCE":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TOKEN_READ":                                   reflect.ValueOf(constant.MakeFromLiteral("131080", token.INT, 0)),
		"TOKEN_WRITE":                                  reflect.ValueOf(constant.MakeFromLiteral("131296", token.INT, 0)),
		"TRUNCATE_EXISTING":                            reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"TerminateProcess":                             reflect.ValueOf(syscall.TerminateProcess),
		"TimespecToNsec":                               reflect.ValueOf(syscall.TimespecToNsec),
		"TokenAccessInformation":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"TokenAuditPolicy":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TokenDefaultDacl":                             reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"TokenElevation":                               reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"TokenElevationType":                           reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"TokenGroups":                                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TokenGroupsAndPrivileges":                     reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"TokenHasRestrictions":                         reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"TokenImpersonationLevel":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"TokenIntegrityLevel":                          reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"TokenLinkedToken":                             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"TokenLogonSid":                                reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"TokenMandatoryPolicy":                         reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"TokenOrigin":                                  reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"TokenOwner":                                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TokenPrimaryGroup":                            reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"TokenPrivileges":                              reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"TokenRestrictedSids":                          reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"TokenSandBoxInert":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"TokenSessionId":                               reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"TokenSessionReference":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TokenSource":                                  reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"TokenStatistics":                              reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"TokenType":                                    reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TokenUIAccess":                                reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"TokenUser":                                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TokenVirtualizationAllowed":                   reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"TokenVirtualizationEnabled":                   reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"TranslateAccountName":                         reflect.ValueOf(syscall.TranslateAccountName),
		"TranslateName":                                reflect.ValueOf(syscall.TranslateName),
		"TransmitFile":                                 reflect.ValueOf(syscall.TransmitFile),
		"UNIX_PATH_MAX":                                reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"USAGE_MATCH_TYPE_AND":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"USAGE_MATCH_TYPE_OR":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"UTF16FromString":                              reflect.ValueOf(syscall.UTF16FromString),
		"UTF16PtrFromString":                           reflect.ValueOf(syscall.UTF16PtrFromString),
		"UTF16ToString":                                reflect.ValueOf(syscall.UTF16ToString),
		"Unlink":                                       reflect.ValueOf(syscall.Unlink),
		"UnmapViewOfFile":                              reflect.ValueOf(syscall.UnmapViewOfFile),
		"Unsetenv":                                     reflect.ValueOf(syscall.Unsetenv),
		"Utimes":                                       reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                                   reflect.ValueOf(syscall.UtimesNano),
		"VirtualLock":                                  reflect.ValueOf(syscall.VirtualLock),
		"VirtualUnlock":                                reflect.ValueOf(syscall.VirtualUnlock),
		"WAIT_ABANDONED":                               reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WAIT_FAILED":                                  reflect.ValueOf(constant.MakeFromLiteral("4294967295", token.INT, 0)),
		"WAIT_OBJECT_0":                                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"WAIT_TIMEOUT":                                 reflect.ValueOf(constant.MakeFromLiteral("258", token.INT, 0)),
		"WSACleanup":                                   reflect.ValueOf(syscall.WSACleanup),
		"WSADESCRIPTION_LEN":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"WSAEACCES":                                    reflect.ValueOf(syscall.WSAEACCES),
		"WSAECONNABORTED":                              reflect.ValueOf(syscall.WSAECONNABORTED),
		"WSAECONNRESET":                                reflect.ValueOf(syscall.WSAECONNRESET),
		"WSAEnumProtocols":                             reflect.ValueOf(syscall.WSAEnumProtocols),
		"WSAID_CONNECTEX":                              reflect.ValueOf(&syscall.WSAID_CONNECTEX).Elem(),
		"WSAIoctl":                                     reflect.ValueOf(syscall.WSAIoctl),
		"WSAPROTOCOL_LEN":                              reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"WSARecv":                                      reflect.ValueOf(syscall.WSARecv),
		"WSARecvFrom":                                  reflect.ValueOf(syscall.WSARecvFrom),
		"WSASYS_STATUS_LEN":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WSASend":                                      reflect.ValueOf(syscall.WSASend),
		"WSASendTo":                                    reflect.ValueOf(syscall.WSASendTo),
		"WSASendto":                                    reflect.ValueOf(syscall.WSASendto),
		"WSAStartup":                                   reflect.ValueOf(syscall.WSAStartup),
		"WaitForSingleObject":                          reflect.ValueOf(syscall.WaitForSingleObject),
		"Write":                                        reflect.ValueOf(syscall.Write),
		"WriteConsole":                                 reflect.ValueOf(syscall.WriteConsole),
		"WriteFile":                                    reflect.ValueOf(syscall.WriteFile),
		"X509_ASN_ENCODING":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"XP1_CONNECTIONLESS":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"XP1_CONNECT_DATA":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"XP1_DISCONNECT_DATA":                          reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"XP1_EXPEDITED_DATA":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"XP1_GRACEFUL_CLOSE":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"XP1_GUARANTEED_DELIVERY":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"XP1_GUARANTEED_ORDER":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"XP1_IFS_HANDLES":                              reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"XP1_MESSAGE_ORIENTED":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"XP1_MULTIPOINT_CONTROL_PLANE":                 reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"XP1_MULTIPOINT_DATA_PLANE":                    reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"XP1_PARTIAL_MESSAGE":                          reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"XP1_PSEUDO_STREAM":                            reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"XP1_QOS_SUPPORTED":                            reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"XP1_SAN_SUPPORT_SDP":                          reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"XP1_SUPPORT_BROADCAST":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"XP1_SUPPORT_MULTIPOINT":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"XP1_UNI_RECV":                                 reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"XP1_UNI_SEND":                                 reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),

		// type definitions
		"AddrinfoW":                   reflect.ValueOf((*syscall.AddrinfoW)(nil)),
		"ByHandleFileInformation":     reflect.ValueOf((*syscall.ByHandleFileInformation)(nil)),
		"CertChainContext":            reflect.ValueOf((*syscall.CertChainContext)(nil)),
		"CertChainElement":            reflect.ValueOf((*syscall.CertChainElement)(nil)),
		"CertChainPara":               reflect.ValueOf((*syscall.CertChainPara)(nil)),
		"CertChainPolicyPara":         reflect.ValueOf((*syscall.CertChainPolicyPara)(nil)),
		"CertChainPolicyStatus":       reflect.ValueOf((*syscall.CertChainPolicyStatus)(nil)),
		"CertContext":                 reflect.ValueOf((*syscall.CertContext)(nil)),
		"CertEnhKeyUsage":             reflect.ValueOf((*syscall.CertEnhKeyUsage)(nil)),
		"CertInfo":                    reflect.ValueOf((*syscall.CertInfo)(nil)),
		"CertRevocationCrlInfo":       reflect.ValueOf((*syscall.CertRevocationCrlInfo)(nil)),
		"CertRevocationInfo":          reflect.ValueOf((*syscall.CertRevocationInfo)(nil)),
		"CertSimpleChain":             reflect.ValueOf((*syscall.CertSimpleChain)(nil)),
		"CertTrustListInfo":           reflect.ValueOf((*syscall.CertTrustListInfo)(nil)),
		"CertTrustStatus":             reflect.ValueOf((*syscall.CertTrustStatus)(nil)),
		"CertUsageMatch":              reflect.ValueOf((*syscall.CertUsageMatch)(nil)),
		"Conn":                        reflect.ValueOf((*syscall.Conn)(nil)),
		"DLL":                         reflect.ValueOf((*syscall.DLL)(nil)),
		"DLLError":                    reflect.ValueOf((*syscall.DLLError)(nil)),
		"DNSMXData":                   reflect.ValueOf((*syscall.DNSMXData)(nil)),
		"DNSPTRData":                  reflect.ValueOf((*syscall.DNSPTRData)(nil)),
		"DNSRecord":                   reflect.ValueOf((*syscall.DNSRecord)(nil)),
		"DNSSRVData":                  reflect.ValueOf((*syscall.DNSSRVData)(nil)),
		"DNSTXTData":                  reflect.ValueOf((*syscall.DNSTXTData)(nil)),
		"Errno":                       reflect.ValueOf((*syscall.Errno)(nil)),
		"FileNotifyInformation":       reflect.ValueOf((*syscall.FileNotifyInformation)(nil)),
		"Filetime":                    reflect.ValueOf((*syscall.Filetime)(nil)),
		"GUID":                        reflect.ValueOf((*syscall.GUID)(nil)),
		"Handle":                      reflect.ValueOf((*syscall.Handle)(nil)),
		"Hostent":                     reflect.ValueOf((*syscall.Hostent)(nil)),
		"IPMreq":                      reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPv6Mreq":                    reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"InterfaceInfo":               reflect.ValueOf((*syscall.InterfaceInfo)(nil)),
		"IpAdapterInfo":               reflect.ValueOf((*syscall.IpAdapterInfo)(nil)),
		"IpAddrString":                reflect.ValueOf((*syscall.IpAddrString)(nil)),
		"IpAddressString":             reflect.ValueOf((*syscall.IpAddressString)(nil)),
		"IpMaskString":                reflect.ValueOf((*syscall.IpMaskString)(nil)),
		"LazyDLL":                     reflect.ValueOf((*syscall.LazyDLL)(nil)),
		"LazyProc":                    reflect.ValueOf((*syscall.LazyProc)(nil)),
		"Linger":                      reflect.ValueOf((*syscall.Linger)(nil)),
		"MibIfRow":                    reflect.ValueOf((*syscall.MibIfRow)(nil)),
		"Overlapped":                  reflect.ValueOf((*syscall.Overlapped)(nil)),
		"Pointer":                     reflect.ValueOf((*syscall.Pointer)(nil)),
		"Proc":                        reflect.ValueOf((*syscall.Proc)(nil)),
		"ProcAttr":                    reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"ProcessEntry32":              reflect.ValueOf((*syscall.ProcessEntry32)(nil)),
		"ProcessInformation":          reflect.ValueOf((*syscall.ProcessInformation)(nil)),
		"Protoent":                    reflect.ValueOf((*syscall.Protoent)(nil)),
		"RawConn":                     reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":                 reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":              reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrInet4":            reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":            reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrUnix":             reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rusage":                      reflect.ValueOf((*syscall.Rusage)(nil)),
		"SID":                         reflect.ValueOf((*syscall.SID)(nil)),
		"SIDAndAttributes":            reflect.ValueOf((*syscall.SIDAndAttributes)(nil)),
		"SSLExtraCertChainPolicyPara": reflect.ValueOf((*syscall.SSLExtraCertChainPolicyPara)(nil)),
		"SecurityAttributes":          reflect.ValueOf((*syscall.SecurityAttributes)(nil)),
		"Servent":                     reflect.ValueOf((*syscall.Servent)(nil)),
		"Signal":                      reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":                    reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrGen":                 reflect.ValueOf((*syscall.SockaddrGen)(nil)),
		"SockaddrInet4":               reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":               reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":                reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"StartupInfo":                 reflect.ValueOf((*syscall.StartupInfo)(nil)),
		"SysProcAttr":                 reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Systemtime":                  reflect.ValueOf((*syscall.Systemtime)(nil)),
		"TCPKeepalive":                reflect.ValueOf((*syscall.TCPKeepalive)(nil)),
		"Timespec":                    reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":                     reflect.ValueOf((*syscall.Timeval)(nil)),
		"Timezoneinformation":         reflect.ValueOf((*syscall.Timezoneinformation)(nil)),
		"Token":                       reflect.ValueOf((*syscall.Token)(nil)),
		"Tokenprimarygroup":           reflect.ValueOf((*syscall.Tokenprimarygroup)(nil)),
		"Tokenuser":                   reflect.ValueOf((*syscall.Tokenuser)(nil)),
		"TransmitFileBuffers":         reflect.ValueOf((*syscall.TransmitFileBuffers)(nil)),
		"UserInfo10":                  reflect.ValueOf((*syscall.UserInfo10)(nil)),
		"WSABuf":                      reflect.ValueOf((*syscall.WSABuf)(nil)),
		"WSAData":                     reflect.ValueOf((*syscall.WSAData)(nil)),
		"WSAProtocolChain":            reflect.ValueOf((*syscall.WSAProtocolChain)(nil)),
		"WSAProtocolInfo":             reflect.ValueOf((*syscall.WSAProtocolInfo)(nil)),
		"WaitStatus":                  reflect.ValueOf((*syscall.WaitStatus)(nil)),
		"Win32FileAttributeData":      reflect.ValueOf((*syscall.Win32FileAttributeData)(nil)),
		"Win32finddata":               reflect.ValueOf((*syscall.Win32finddata)(nil)),

		// interface wrapper definitions
		"_Conn":     reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":  reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_Sockaddr": reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
