// Code generated by 'yaegi extract cmp'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package stdlib

import (
	"reflect"
)

func init() {
	Symbols["cmp/cmp"] = map[string]reflect.Value{}
}
